[−]Struct gdnative_core::euclid::Length
A one-dimensional distance, with value represented by T and unit of measurement Unit.
T can be any numeric type, for example a primitive type like u64 or f32.
Unit is not used in the representation of a Length value. It is used only at compile time
to ensure that a Length stored with one unit is converted explicitly before being used in an
expression that requires a different unit. It may be a type without values, such as an empty
enum.
You can multiply a Length by a scale::TypedScale to convert it from one unit to
another. See the TypedScale docs for an example.
Methods
impl<T, Unit> Length<T, Unit>
impl<T, Unit> Length<T, Unit>impl<Unit, T> Length<T, Unit> where
T: Clone,
impl<Unit, T> Length<T, Unit> where
T: Clone, pub fn get(&self) -> T |
impl<Unit, T0> Length<T0, Unit> where
T0: Clone + NumCast,
impl<Unit, T0> Length<T0, Unit> where
T0: Clone + NumCast, pub fn cast<T1>(&self) -> Length<T1, Unit> where |
Cast from one numeric representation to another, preserving the units.
pub fn try_cast<T1>(&self) -> Option<Length<T1, Unit>> where |
Fallible cast from one numeric representation to another, preserving the units.
impl<T, U> Length<T, U> where
T: One + Add<T, Output = T> + Sub<T, Output = T> + Mul<T, Output = T> + Copy,
impl<T, U> Length<T, U> where
T: One + Add<T, Output = T> + Sub<T, Output = T> + Mul<T, Output = T> + Copy, pub fn lerp(&self, other: Length<T, U>, t: T) -> Length<T, U> |
Linearly interpolate between this length and another length.
t is expected to be between zero and one.