pub trait Export: ToVariant {
type Hint;
// Required method
fn export_info(hint: Option<Self::Hint>) -> ExportInfo;
}Expand description
Trait for exportable types.
Required Associated Types
Sourcetype Hint
type Hint
A type-specific hint type that is valid for the type being exported.
If this type shows up as NoHint, a private, uninhabitable type indicating
that there are no hints available for the time being, users must use None
for properties of this type. This ensures that it will not be a breaking change
to add a hint for the type later, since it supports no operations and cannot
be named directly in user code.
Required Methods
Sourcefn export_info(hint: Option<Self::Hint>) -> ExportInfo
fn export_info(hint: Option<Self::Hint>) -> ExportInfo
Returns ExportInfo given an optional typed hint.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".