[]Struct gdnative_core::init::PropertyUsage

pub struct PropertyUsage { /* fields omitted */ }

Methods

impl PropertyUsage

pub const STORAGE: PropertyUsage

pub const EDITOR: PropertyUsage

pub const NETWORK: PropertyUsage

pub const EDITOR_HELPER: PropertyUsage

pub const CHECKABLE: PropertyUsage

pub const CHECKED: PropertyUsage

pub const INTERNATIONALIZED: PropertyUsage

pub const GROUP: PropertyUsage

pub const CATEGORY: PropertyUsage

pub const STORE_IF_NONZERO: PropertyUsage

pub const STORE_IF_NONONE: PropertyUsage

pub const NO_INSTANCE_STATE: PropertyUsage

pub const RESTART_IF_CHANGED: PropertyUsage

pub const SCRIPT_VARIABLE: PropertyUsage

pub const STORE_IF_NULL: PropertyUsage

pub const ANIMATE_AS_TRIGGER: PropertyUsage

pub const UPDATE_ALL_IF_MODIFIED: PropertyUsage

pub const DEFAULT: PropertyUsage

pub const DEFAULT_INTL: PropertyUsage

pub const NOEDITOR: PropertyUsage

pub fn empty() -> PropertyUsage

Returns an empty set of flags.

pub fn all() -> PropertyUsage

Returns the set containing all flags.

pub fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<PropertyUsage>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub fn from_bits_truncate(bits: u32) -> PropertyUsage

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub fn intersects(&self, other: PropertyUsage) -> bool

Returns true if there are flags common to both self and other.

pub fn contains(&self, other: PropertyUsage) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: PropertyUsage)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: PropertyUsage)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: PropertyUsage)

Toggles the specified flags in-place.

pub fn set(&mut self, other: PropertyUsage, value: bool)

Inserts or removes the specified flags depending on the passed value.

impl PropertyUsage
[src]