pub fn error<S: Display>(site: Site<'_>, msg: S)Expand description
Print an error to the Godot console.
Typically, you would use this through the godot_error macro.
Panics
If the API isn’t initialized, or if the message contains any NUL-bytes.
pub fn error<S: Display>(site: Site<'_>, msg: S)Print an error to the Godot console.
Typically, you would use this through the godot_error macro.
If the API isn’t initialized, or if the message contains any NUL-bytes.