pub fn warn<S: Display>(site: Site<'_>, msg: S)Expand description
Print a warning to the Godot console.
Typically, you would use this through the godot_warn macro.
Panics
If the API isn’t initialized, or if the message contains any NUL-bytes.
pub fn warn<S: Display>(site: Site<'_>, msg: S)Print a warning to the Godot console.
Typically, you would use this through the godot_warn macro.
If the API isn’t initialized, or if the message contains any NUL-bytes.