Trait gdnative_core::ref_kind::RefKind [−][src]
Trait to parameterize over the memory management markers
ManuallyManaged and RefCounted.
This trait is sealed and has no public members.
Trait to parameterize over the memory management markers
ManuallyManaged and RefCounted.
This trait is sealed and has no public members.
impl RefKind for ManuallyManaged[src]impl RefKind for RefCounted[src]