Struct gdnative_core::Rid [−][src]
pub struct Rid(_);
The RID type is used to access the unique integer ID of a resource. They are opaque, so they do not grant access to the associated resource by themselves.
Methods
impl Rid[src]
impl Ridpub fn new() -> Self[src]
pub fn new() -> Selfpub fn get_id(&self) -> i32[src]
pub fn get_id(&self) -> i32pub fn operator_less(&self, b: &Rid) -> bool[src]
pub fn operator_less(&self, b: &Rid) -> boolpub fn is_valid(&self) -> bool[src]
pub fn is_valid(&self) -> boolTrait Implementations
impl<'l> From<&'l Rid> for Variant[src]
impl<'l> From<&'l Rid> for Variantimpl Copy for Rid[src]
impl Copy for Ridimpl Clone for Rid[src]
impl Clone for Ridfn clone(&self) -> Rid[src]
fn clone(&self) -> RidReturns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Debug for Rid[src]
impl Debug for Ridfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for Rid[src]
impl PartialEq for Ridfn eq(&self, other: &Self) -> bool[src]
fn eq(&self, other: &Self) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0[src]
fn ne(&self, other: &Rhs) -> boolThis method tests for !=.
impl Eq for Rid[src]
impl Eq for Ridimpl Default for Rid[src]
impl Default for Ridimpl PartialOrd for Rid[src]
impl PartialOrd for Ridfn partial_cmp(&self, other: &Rid) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &Rid) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &Rhs) -> bool1.0.0[src]
fn lt(&self, other: &Rhs) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &Rhs) -> bool1.0.0[src]
fn le(&self, other: &Rhs) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &Rhs) -> bool1.0.0[src]
fn gt(&self, other: &Rhs) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &Rhs) -> bool1.0.0[src]
fn ge(&self, other: &Rhs) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more