[−][src]Module gdnative_core::init
Types and functionalities to declare and initialize gdnative classes.
API endpoints
Three endpoints are automatically invoked by the engine during startup and shutdown:
All three must be present.
Registering a class using the godot_class macro
See the spinning_cube example in the repositiory.
Registering a class manually
See the manually_registered example in the repositiory.
Re-exports
pub use self::property::Export; |
pub use self::property::ExportInfo; |
pub use self::property::PropertyBuilder; |
pub use self::property::Usage as PropertyUsage; |
Modules
| property | Property registration. |
Structs
| ClassBuilder | |
| ClassDescriptor | |
| InitHandle | A handle that can register new classes to the engine during initialization. |
| ScriptMethod | |
| ScriptMethodAttributes | |
| Signal | |
| SignalArgument |
Enums
| RpcMode |
Type Definitions
| ScriptConstructorFn | |
| ScriptDestructorFn | |
| ScriptMethodFn |