Struct gdnative_core::init::InitHandle[][src]

pub struct InitHandle { /* fields omitted */ }

A handle that can register new classes to the engine during initialization.

See godot_nativescript_init.

Methods

impl InitHandle
[src]

Registers a new class to the engine.

The return ClassBuilder can be used to add methods, signals and properties to the class.