Struct gdnative_core::init::InitHandle [−][src]
pub struct InitHandle { /* fields omitted */ }A handle that can register new classes to the engine during initialization.
Methods
impl InitHandle[src]
impl InitHandlepub fn add_class<C>(&self, desc: ClassDescriptor) -> ClassBuilder<C> where
C: NativeClass, [src]
pub fn add_class<C>(&self, desc: ClassDescriptor) -> ClassBuilder<C> where
C: NativeClass, Registers a new class to the engine.
The return ClassBuilder can be used to add methods, signals and properties
to the class.