Various traits to verify memory policy, ownership policy or lifetime bounds
The symbols defined in this module are internal and used to enhance type safety. You typically will not need to work with them.
Structs
- Forget
- Simply releases the held object without deallocating it.
- RefImpl
Bound - Struct to be used for various
Reftrait bounds. - UnRef
- Decrements the reference count on the held object, deallocating it if it’s the last ref.
Traits
- Lifetime
Constraint - Trait for constraining
assume_safelifetimes to the one of&selfwhenTis reference-counted. This is an internal interface. - Memory
Spec - Specialization trait depending on
Memory. This is an internal interface. - PtrWrapper
- Specialization trait for
Dropbehavior. - Safe
AsRaw - Trait for persistent
Refs that point to valid objects. This is an internal interface. - Safe
Deref - Trait for combinations of
MemoryandOwnershipthat can be dereferenced safely. This is an internal interface.